@@ -20,15 +20,16 @@ def isserviceactive(SERVICENAME):
     STATUS = os.system("systemctl status %s 1> /dev/null" % SERVICENAME)
     print(STATUS)
     if STATUS == 0:
-        print(bcolors.OKGREEN + SERVICENAME + " Seems to be running"  + bcolors.ENDC)
+        print(bcolors.OKGREEN + SERVICENAME + " seems to be running"  + bcolors.ENDC)
+        time.sleep(0.5)
     elif STATUS == 768:
-        print(bcolors.FAIL + SERVICENAME + " Service installed but not running"  + bcolors.ENDC)
+        print(bcolors.FAIL + SERVICENAME + " service installed but not running"  + bcolors.ENDC)
     else: 
-        print(bcolors.FAIL + SERVICENAME + " Seems like service is not installed"  + bcolors.ENDC)
+        print(bcolors.FAIL + SERVICENAME + " seems like service is not installed"  + bcolors.ENDC)
         sys.exit(1)
 
 def isserviceenabled(SERVICENAME):
-    output = subprocess.check_output("systemctl status %s" % SERVICENAME, shell=True)
+    output = subprocess.check_output("systemctl status %s 1> /dev/null" % SERVICENAME, shell=True)
     output = output.decode()
     if "enabled; vendor preset" in output and os.path.isfile("/usr/lib/systemd/system/%s.service" % SERVICENAME):
         print(bcolors.OKGREEN + SERVICENAME + " service is enabled"  + bcolors.ENDC)
